summaryrefslogtreecommitdiffstats
path: root/chrome/browser/net/url_request_tracking.h
diff options
context:
space:
mode:
authorajwong@chromium.org <ajwong@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-05 01:09:10 +0000
committerajwong@chromium.org <ajwong@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-05 01:09:10 +0000
commit434f98fe56928cc05a15d9ff9678d81b26812cf3 (patch)
treeb925fe2d3b78a897f1216ac15cd2112b08d65499 /chrome/browser/net/url_request_tracking.h
parent5d066c8c93c0a272095228c0f4e0d135d4fa4417 (diff)
downloadchromium_src-434f98fe56928cc05a15d9ff9678d81b26812cf3.zip
chromium_src-434f98fe56928cc05a15d9ff9678d81b26812cf3.tar.gz
chromium_src-434f98fe56928cc05a15d9ff9678d81b26812cf3.tar.bz2
Fix Task Manager to correctly display network usage of plug-in processes.
BUG=chromium-os:2954 TEST=Run Chrome and open Task Manager, then play a video in YouTube and check whether the Network usage is correctly reported against the plug-in. Review URL: http://codereview.chromium.org/6328010 Patch from James Weatherall <wez@chromium.org>. git-svn-id: svn://svn.chromium.org/chrome/trunk/src@73884 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/net/url_request_tracking.h')
-rw-r--r--chrome/browser/net/url_request_tracking.h23
1 files changed, 11 insertions, 12 deletions
diff --git a/chrome/browser/net/url_request_tracking.h b/chrome/browser/net/url_request_tracking.h
index 0e7a7156..497dfb2 100644
--- a/chrome/browser/net/url_request_tracking.h
+++ b/chrome/browser/net/url_request_tracking.h
@@ -18,20 +18,19 @@ namespace chrome_browser_net {
// place allows us to do more general things, such as assigning traffic for the
// network view in the task manager.
//
// If you make a request on behalf of a child process, please call this
// function. The default value will be -1 which will be interprepreted as
// originating from the browser itself.
//
-// The ID is the child process' unique ID (not a PID) of the process originating
-// the request. This is normally the renderer corresponding to the load. If a
-// plugin process does a request through a renderer process this will be the
-// plugin (the originator of the request).
-void SetOriginProcessUniqueIDForRequest(int id, net::URLRequest* request);
+// TODO(wez): Get rid of the zero-PID hack & enforce that one is always set.
+void SetOriginPIDForRequest(int pid, net::URLRequest* request);
-// Returns the child process' unique ID that has been previously set by
-// SetOriginProcessUniqueIDForRequest. If no ID has been set, the return
-// value is -1. We use this to identify requests made by the browser process.
-int GetOriginProcessUniqueIDForRequest(const net::URLRequest* request);
+// Returns the process ID of the request's originator, previously stored with
+// SetOriginProcessIDForRequest, or zero if no PID has been set. A PID of zero
+// should be interpreted as meaning the request originated from a renderer
+// process, or within the browser itself.
+int GetOriginPIDForRequest(const net::URLRequest* request);
} // namespace chrome_browser_net
@@ -18,20 +18,19 @@ namespace chrome_browser_net {
// network view in the task manager.
//
-// If you make a request on behalf of a child process, please call this
-// function. The default value will be -1 which will be interprepreted as
-// originating from the browser itself.
+// If you make a request on behalf of a child process other than a renderer,
+// please call this function to store its PID (NOT its browser-assigned unique
+// child ID). For requests originating in a renderer or the browser itself,
+// set a PID of zero (the default).
//